<?php 
class CoreObject
{
	public $ID;
	public $Title;
	public $Slug;
	public $Description;
	public $Image;
	public $DateCreated;
	public $DateModified;
	
	public static function Get(){
		return new static();
	}
	
	public function ByID($postid) {
		$post = get_post($postid);
		return self::Get()->ByPost($post);
	}
	public function ByPost($post) {
		$this->ID = $post->ID;
		$this->Title = $post->post_title;
		$this->Slug = $post->post_name;
		$this->Description = $post->post_content;
		$this->DateCreated = $post->post_date;
		$this->DateModified = $post->post_modified;
		return $this;
	}
	
	public function GetFeaturedImage($returnhtml = false)
	{
		if( $returnhtml== false && $this->Image != "" ) return $this->Image;
		$imagepath = wp_get_attachment_url( get_post_thumbnail_id($this->ID));
		if($imagepath != null && $imagepath != "")
		{
			$this->Image = $imagepath;
			if($returnhtml == true) return "<img src='".$imagepath."' alt='".$this->Title."'>";
			else return $imagepath;
		}		
		else return "";
	}
	
	public function GetThumbnail($returnhtml = false, $size = "thumbnail")
	{
		$imagepath = wp_get_attachment_image_src( get_post_thumbnail_id( $this->ID ), $size );
		if(isset($imagepath[0]) && $imagepath[0] != "")
		{
			if($returnhtml == true) return "<img src='".$imagepath[0]."' alt='".$this->Title."'>";
			return $imagepath[0];
		}
		else
		{
			return "";
		}
	}
	
	public function GenerateBreadcrumbs()
	{
		ob_start();
		?>
		<div id="postbreadcrumbs">
			<ul itemscope itemtype="http://schema.org/BreadcrumbList">
				<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">
					<a itemprop="url" href="/"><span itemprop="name">Home</span></a>
					<meta itemprop="position" content="1" />
				</li>
				<li class="breadcrumbseparator"> > </li>
				<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">
					<a itemprop="url" href="/"><span itemprop="name"><?php echo $this->Title;?></span></a>
					<meta itemprop="position" content="2" />
				</li>
			</ul>
			<div style="clear:both"></div>
		</div>
		<?php 
		$crumbs = ob_get_clean();
		return $crumbs;
	}
	
	public function GenerateSummary()
	{
		$paragraphs = explode("</p>", str_replace("<p>&nbsp;</p>", "", apply_filters ("the_content", $this->Description)));
		$output = $paragraphs[0];
		if(strlen($paragraphs[0]) >= 600) $output = substr($paragraphs[0], 0, 600)."...";
		return "<p>".strip_tags($output)."</p>";
	}
	
	public function GenerateBrief()
	{
		$paragraphs = explode("</p>", str_replace("<p>&nbsp;</p>", "", apply_filters ("the_content", $this->Description)));
		$output = $paragraphs[0];
		if(strlen($output) >= 140) $output = substr($output, 0, 150)."...";
		return "<p>".strip_tags($output)."</p>";
	}
	
	public function GetListTile()
	{
		return "";
	}
	
	public function GetCommentCount()
	{
		//[approved] => 0 [spam] => 0 [trash] => 0 [post-trashed] => 0 [total_comments] => 0 [all] => 0 [moderated] => 0
		return wp_count_comments($this->ID)->approved;
	}
	
	public function GetAuthor()
	{
		return get_the_author();
	}
	
	public function GetTags()
	{
		//WP_Term Object ( [term_id] => 3 [name] => tag1 [slug] => tag1 [term_group] => 0 [term_taxonomy_id] => 3 [taxonomy] => post_tag [description] => [parent] => 0 [count] => 1 [filter] => raw ) 
		$tags = wp_get_post_tags($this->ID);
		$output = "";
		foreach($tags as $tag)
		{
			$output .= $tag->name.",";
		}
		return rtrim($output, ",");
	}
	
	public function GeneratePostMetaDetails()
	{
		$categories = get_the_category($this->ID);
		$categorystring = "";
		foreach($categories as $category)
		{
			$categorystring .= "<span class='metacategory'><a href='/category/".$category->slug."'>".$category->name."</a></span>";
		}
		
		return "<span id='postpublished'>Published : ".$this->DateCreated."</span> ".$categorystring;
	}
	
	public function GenerateCleanDateTime()
	{
		return date("F jS Y, h:ia", strtotime($this->DateCreated));
	}
}