<?php
defined( 'ABSPATH' ) or die( 'Error' );
function load_band_blogpost_widget() {
	register_widget( 'band_blogpost_widget' );
}
add_action( 'widgets_init', 'load_band_blogpost_widget' );

class band_blogpost_widget extends WP_Widget {

	public function __construct() {
		$widget_ops = array( 
			'classname' => 'band_blogpost_widget',
			'description' => 'Advanced plugin to display blog posts using various templates and query options.',
		);
		parent::__construct( 'band_blogpost_widget', 'Blog Posts', $widget_ops );
	}

	public function widget( $args, $instance ) {
		require_once bandmanager_themeRootDir()."/objects/coreobject.class.php";
		
		if(isset($instance["querytype"]) && $instance["querytype"] != "") {
			$queryargs = array('post_type' => 'post');
			//echo $instance["querytype"];
			switch($instance["querytype"])
			{
				case "latestposts": 
					$queryargs = array_merge($queryargs, array('posts_per_page' => $instance['futurelimit'], "orderby" => "date"));
				break;
				
				case "singlepost": 
					$queryargs["pagename"] = $instance["postslug"];
				break;
				
				case "daterange": 
					$queryargs = array_merge($queryargs, 
						array('date_query' => 
							array (
								array (
									'after'     => 	$instance['startdate'],
									'before'	=>	$instance['enddate'],
									'inclusive' => 	true,
								),
							),
							"posts_per_page" => $instance['rangelimit']
						));
				break;
			}
			
			$queryargs['order'] = $instance['orderby'];
			$query = new WP_Query($queryargs);
			$posts = $query->get_posts();
			
			?>
			<aside id="gig_widget" class="widget widget_meta postwidget<?php echo $instance['template'];?>"><h2 class="widget-title"><?php echo $instance['title'];?></h2><?php
			if(count($posts) != 0) {
				foreach($posts as $post)
				{
					$bandpost = CoreObject::Get()->ByPost($post);
					$postwallpaper = $bandpost->GetThumbnail(false, "medium");
					switch($instance['template'])
					{
						case "minimal":
							echo "<a href='".$bandpost->Slug."'>".$bandpost->Title."</a><br>";
						break;
						
						case "basic":
							?><p>
								<a href="<?php echo $bandpost->Slug;?>"><?php echo $bandpost->Title;?></a><br>
								<span class="postwidgetsubtext"><strong><?php echo $bandpost->GetAuthor();?></strong> - <?php echo $bandpost->DateCreated;?></span>
							</p><?php 
						break;
						
						case "standard":
							?><div class="widgetpost">
								<?php if(trim($postwallpaper) != "") { ?><a href="<?php echo $bandpost->Slug;?>"><img src="<?php echo $postwallpaper;?>" class="postthumbnail" alt="<?php echo str_replace('"', "", $bandpost->Title);?> thumbnail"/></a> <?php } ?>
								<a href="<?php echo $bandpost->Slug;?>"><strong><?php echo $bandpost->Title;?></strong></a><br>
								<div class="postwidgetsubtext">
									<strong><?php echo $bandpost->GetAuthor();?></strong> - <?php echo bandmanager_getPrettyDate($bandpost->DateCreated);?>
								</div>
								<div style="clear:both;"></div>
							</div><?php 
						break;
						
						case "detailed":	
							?><div class="widgetpost">
								<?php if(trim($postwallpaper) != "") { ?><a href="<?php echo $bandpost->Slug;?>"><img src="<?php echo $postwallpaper;?>" class="postthumbnail" alt="<?php echo str_replace('"', "", $bandpost->Title);?> thumbnail"/></a> <?php } ?>
								<div class="postdetail">
									<a class="widgetposttitle" href="<?php echo $bandpost->Slug;?>"><strong><?php echo $bandpost->Title;?></strong></a><br>
									<div class="postwidgetsubtext">
										<strong><?php echo $bandpost->GetAuthor();?></strong> - <?php echo bandmanager_getPrettyDate($bandpost->DateCreated);?>
										<span class="commentcount"><i class="fa fa-comment"></i><?php echo $bandpost->GetCommentCount();?></span>
									</div>
								</div>
								<div style="clear:both;"></div>
							</div><?php 					
						break;
						
						case "complete":		
							?><div class="widgetpost">
								<?php if(trim($postwallpaper) != "") { ?><a href="<?php echo $bandpost->Slug;?>"><img src="<?php echo $postwallpaper;?>" class="postthumbnail" alt="<?php echo str_replace('"', "", $bandpost->Title);?> thumbnail"/></a> <?php } ?>
								<div class="postdetail">
									<a class="widgetposttitle" href="<?php echo $bandpost->Slug;?>"><strong><?php echo $bandpost->Title;?></strong></a><br>
									<div class="postwidgetsubtext">
										<strong><?php echo $bandpost->GetAuthor();?></strong> - <?php echo bandmanager_getPrettyDate($bandpost->DateCreated);?>
										<span class="commentcount"><i class="flaticon-interface widgetcommentcount"></i><?php echo $bandpost->GetCommentCount();?></span>
									</div>
									<?php echo $bandpost->GenerateBrief();?>
								</div>
								<div style="clear:both;"></div>
							</div><?php 					
						break;
					}
				}
			}
			?></aside><?php 
		}
	}

	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] )) {
			$title = $instance[ 'title' ];
			$querytype = $instance['querytype'];
			$template = $instance['template'];
			$futurelimit = $instance['futurelimit'];
			$postslug = $instance['postslug'];
			$startdate = $instance['startdate'];
			$enddate = $instance['enddate'];
			$rangelimit = $instance['rangelimit'];
			$orderby = $instance['orderby'];
		}
		else {
			$title = __( 'New title', 'dx2bandtheme' );
			$querytype = 'latestposts';
			$template = 'detailed';
			$futurelimit = '0';
			$postslug = '';
			$startdate = date('Y-m')."-01";
			$enddate = date('Y-m')."-28";
			$rangelimit = '0';
			$orderby = "ASC";
		}
		?>
			<div class="widgetformwrapper" id="postwidgetformwrapper<?php echo $this->number;?>">
				<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title</label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /><br>
				
				<label for="<?php echo $this->get_field_id( 'querytype' ); ?>">Query Type</label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'querytype' ); ?>" name="<?php echo $this->get_field_name( 'querytype' ); ?>" onchange="showPostQueryTypeFields('<?php echo $this->get_field_id( 'querytype' ); ?>', <?php echo $this->number;?>)">
					<option value="latestposts" <?php if($querytype=="latestposts") echo "selected";?>>Latest Posts</option>
					<option value="singlepost" <?php if($querytype=="singlepost") echo "selected";?>>Single Post</option>
					<option value="postdaterange" <?php if($querytype=="postdaterange") echo "selected";?>>Date Range</option>
				</select>
					<div id="latestposts" class="drilldownfields">
						<label for="<?php echo $this->get_field_id( 'futurelimit' ); ?>">Limit</label> 
						<input class="widefat" id="<?php echo $this->get_field_id( 'futurelimit' ); ?>" name="<?php echo $this->get_field_name( 'futurelimit' ); ?>" type="text" value="<?php echo esc_attr( $futurelimit ); ?>" /><br>
					</div>
					<div id="singlepost" class="drilldownfields">
						<label for="<?php echo $this->get_field_id( 'postslug' ); ?>">Post Slug</label> 
						<input class="widefat" id="<?php echo $this->get_field_id( 'postslug' ); ?>" name="<?php echo $this->get_field_name( 'postslug' ); ?>" type="text" value="<?php echo esc_attr( $postslug ); ?>" /><br>
					</div>
					<div id="postdaterange" class="drilldownfields">
						<label for="<?php echo $this->get_field_id( 'startdate' ); ?>">Start Date</label> 
						<input class="widefat datefield datepicker" id="<?php echo $this->get_field_id( 'startdate' ); ?>" name="<?php echo $this->get_field_name( 'startdate' ); ?>" type="text" value="<?php echo esc_attr( $startdate ); ?>" /><br>
						<label for="<?php echo $this->get_field_id( 'enddate' ); ?>">End Date</label> 
						<input class="widefat datefield datepicker" id="<?php echo $this->get_field_id( 'enddate' ); ?>" name="<?php echo $this->get_field_name( 'enddate' ); ?>" type="text" value="<?php echo esc_attr( $enddate ); ?>" /><br>
						<label for="<?php echo $this->get_field_id( 'rangelimit' ); ?>">Limit</label> 
						<input class="widefat" id="<?php echo $this->get_field_id( 'rangelimit' ); ?>" name="<?php echo $this->get_field_name( 'rangelimit' ); ?>" type="text" value="<?php echo esc_attr( $rangelimit ); ?>" /><br>
					</div>
				<label for="<?php echo $this->get_field_id( 'template' ); ?>">Template</label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'template' ); ?>" name="<?php echo $this->get_field_name( 'template' ); ?>">
					<option value="minimal" <?php if($template=="minimal") echo "selected";?>>Minimal</option>
					<option value="basic" <?php if($template=="basic") echo "selected";?>>Basic</option>
					<option value="standard" <?php if($template=="standard") echo "selected";?>>Standard</option>
					<option value="detailed" <?php if($template=="detailed") echo "selected";?>>Detailed</option>
					<option value="complete" <?php if($template=="complete") echo "selected";?>>Complete</option>
				</select>
				
				<label for="<?php echo $this->get_field_id( 'orderby' ); ?>">Order By</label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>">
					<option value="DESC" <?php if($orderby=="DESC") echo "selected";?>>Newest First</option>
					<option value="ASC" <?php if($orderby=="ASC") echo "selected";?>>Oldest First</option>
				</select>
			</div>
		<?php 
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = strip_tags( $new_instance['title']);
		$instance['querytype'] = strip_tags( $new_instance['querytype']);
		$instance['template'] = strip_tags( $new_instance['template']);
		$instance['futurelimit'] = strip_tags( $new_instance['futurelimit']);
		$instance['postslug'] = strip_tags( $new_instance['postslug']);
		$instance['startdate'] = strip_tags( $new_instance['startdate']);
		$instance['enddate'] = strip_tags( $new_instance['enddate']);
		$instance['rangelimit'] = strip_tags( $new_instance['rangelimit']);
		$instance['orderby'] = strip_tags( $new_instance['orderby']);
		return $instance;
	}
}