<?php
defined( 'ABSPATH' ) or die( 'Error' );
class band_gig_widget extends WP_Widget 
{
	function __construct() 
	{
		parent::__construct('band_gig_widget', __('Gig Listing', 'dx2bandtheme'), array( 'description' => __( 'Will display a listing of your bands gigs defined by the settings below.', 'dx2bandtheme' )));
	}
	public function widget( $args, $instance ) 
	{
		if(isset($instance["querytype"]) && $instance["querytype"])
		{
			require_once plugin_dir_path(__FILE__)."../objects/gig.class.php";

			$queryargs = array('post_type' => 'gig');
			switch($instance["querytype"])
			{
				case "upcominggigs": 
					$queryargs = array_merge($queryargs, array('meta_key' => 'gig_date', 'meta_value' => date('Y-m-d'), 'meta_compare' => '>=', 'type' => 'DATE', 'posts_per_page' => $instance['futurelimit']));
				break;
				
				case "pastgigs": 
					$queryargs = array_merge($queryargs, array('meta_key' => 'gig_date', 'meta_value' => date('Y-m-d'), 'meta_compare' => '<', 'type' => 'DATE','posts_per_page' => $instance['pastlimit']));
				break;
				
				case "singlegig": 
					if(trim($instance["gigslug"]) == "") $instance["gigslug"] = "xx-missing-xx"; 
					$queryargs["name"] = $instance["gigslug"];
					$queryargs["posts_per_page"] = 1;
				break;
				
				case "daterange": 
					$queryargs = array_merge($queryargs, array(
						'orderby' => 'meta_value',
						'meta_key' => 'gig_date',
						'meta_query' => array(
							array(
								'key' => 'gig_date', 
								'value' => array($instance['startdate'], $instance['enddate']),
								'compare' => 'BETWEEN', 
								'type' => 'DATE',
							),
						),'posts_per_page' => $instance['rangelimit']));
				break;
			}
			
			$queryargs['order'] = $instance['orderby'];
			
			//var_dump($queryargs);
			$query = new WP_Query($queryargs);
			$gigs = $query->get_posts();
			//["title"]=> string(13) "Upcoming Gigs" ["querytype"]=> string(9) "daterange" ["template"]=> string(5) "basic" ["futurelimit"]=> string(1) "9" ["pastlimit"]=> string(1) "9" ["gigslug"]=> string(0) "" ["startdate"]=> string(10) "2016-06-01" ["enddate"]=> string(10) "2016-06-30" }
			?>
			<aside id="gig_widget" class="widget widget_meta"><h2 class="widget-title"><?php echo $instance['title'];?></h2>
				<div class="gigwidgetcontent">
				<?php 
				//echo print_r($query);
				if(count($gigs) == 0) {
					echo "No Gigs Found";
				}
				else {
					foreach($gigs as $gig)
					{
						$gigobj = Gig::Get()->ByPost($gig);
						switch($instance['template'])
						{
							case "minimal":
								echo bandmanager_getPrettyDate($gigobj->GigDate, false)." - ".$gigobj->Location."<br>";
							break;
							case "basic":
							?>
								<div class="giglistbasic">
									<strong><a href="/gig/<?php echo $gigobj->Slug;?>"><?php echo $gigobj->Title;?></a></strong>
									<div class="gigbreakdown">
										Date : <?php echo bandmanager_getPrettyDate($gigobj->GigDate, false);?><br>
										Location : <?php echo $gigobj->Location;?>, <?php echo $gigobj->Address;?>
									</div>
								</div>
							<?php 
							break;
							case "detailed":
							case "detailednoimg":
								if($instance['template'] != "detailednoimg") $gigwallpaper = $gigobj->GetFeaturedImage(false);
							?>
								<div class="giglistdetailed" itemscope itemtype="http://schema.org/Event">
									<span itemprop="performer" content="<?php echo get_option('band_name');?>">
									<span itemprop="description" content="<?php echo str_replace('"', "'", strip_tags($gigobj->GenerateSummary()));?>">					
									<?php if($instance['template'] != "detailednoimg" && $gigwallpaper!= "") { ?>
										<a href="/gig/<?php echo $gigobj->Slug;?>">
										<span itemprop="image" itemscope itemtype="http://schema.org/ImageObject">
											<img itemprop="url" src="<?php echo $gigwallpaper;?>" itemprop="image" alt="Event Wallpaper">
										</span>
									</a>
									<?php } ?>
									<strong itemprop="name"><a href="/gig/<?php echo $gigobj->Slug;?>" itemprop="url"><?php echo $gigobj->Title;?></a></strong>
									<div class="gigbreakdown">
										Date : <span itemprop="startDate" content="<?php echo $gigobj->GigDate;?>"></span><?php echo bandmanager_getPrettyDate($gigobj->GigDate, false);?><br>
										<span itemprop="endDate" content="<?php echo $gigobj->generateEndDate();?>"></span>
										Location :<span itemprop="location" itemscope itemtype="http://schema.org/Place">
											<span itemprop="name" ><?php echo $gigobj->Location;?>, <?php echo $gigobj->Address;?></span>
											<span itemprop="address" itemscope itemtype="http://schema.org/PostalAddress" content="<?php echo $gigobj->Address;?>"></span>
										</span><br>
										<?php if($gigobj->DoorsOpen != "") { ?>
											Doors Open : <span itemprop="doorTime"><?php echo $gigobj->DoorsOpen;?></span><br>
										<?php } ?>
										<?php if($gigobj->AdmissionCost != "") { ?>
											Cost : <span itemprop="offers" itemscope itemtype="http://schema.org/Offer">
												<span itemprop="price" content="<?php echo preg_replace("/[^0-9,.]/", "", $gigobj->AdmissionCost);?>"></span><?php echo $gigobj->AdmissionCost;?>
												<span itemprop="url" content="/gig/<?php echo $gigobj->Slug;?>"></span>
										<?php } ?>
									</div>
								</div>
							<?php 						
							break;
						}
					}
				}
				?>
				</div>
			</aside>
			<?php	
		}
	}
		
	// Widget Backend 
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) 
		{
			$title = $instance[ 'title' ];
			$querytype = $instance['querytype'];
			$template = $instance['template'];
			$futurelimit = $instance['futurelimit'];
			$pastlimit = $instance['pastlimit'];
			$gigslug = $instance['gigslug'];
			$startdate = $instance['startdate'];
			$enddate = $instance['enddate'];
			$rangelimit = $instance['rangelimit'];
			$orderby = $instance['orderby'];
		}
		else {
			$title = __( 'New title', 'dx2bandtheme' );
			$querytype = 'upcominggigs';
			$template = 'detailed';
			$futurelimit = '5';
			$pastlimit = '5';
			$gigslug = '';
			$startdate = date('Y-m')."-01";
			$enddate = date('Y-m')."-28";
			$rangelimit = '5';
			$orderby = "ASC";
		}
		// Widget admin form

		?>
		<div id="gigwidgetformwrapper<?php echo $this->number;?>">
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title</label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /><br>
			
			<label for="<?php echo $this->get_field_id( 'querytype' ); ?>">Query Type</label>
			<select class="widefat" id="gigquerytype" name="<?php echo $this->get_field_name( 'querytype' ); ?>" onchange="showQueryTypeFields(<?php echo $this->number;?>)">
				<option value="upcominggigs" <?php if($querytype=="upcominggigs") echo "selected";?>>Upcoming Gigs</option>
				<option value="pastgigs" <?php if($querytype=="pastgigs") echo "selected";?>>Past Gigs</option>
				<option value="singlegig" <?php if($querytype=="singlegig") echo "selected";?>>Single Gig</option>
				<option value="daterange" <?php if($querytype=="daterange") echo "selected";?>>Date Range</option>
			</select>
				<div id="upcominggigs" class="drilldownfields">
					<label for="<?php echo $this->get_field_id( 'futurelimit' ); ?>">Limit</label> 
					<input class="widefat" id="<?php echo $this->get_field_id( 'futurelimit' ); ?>" name="<?php echo $this->get_field_name( 'futurelimit' ); ?>" type="text" value="<?php echo esc_attr( $futurelimit ); ?>" /><br>
				</div>
				<div id="pastgigs" class="drilldownfields">
					<label for="<?php echo $this->get_field_id( 'pastlimit' ); ?>">Limit</label> 
					<input class="widefat" id="<?php echo $this->get_field_id( 'pastlimit' ); ?>" name="<?php echo $this->get_field_name( 'pastlimit' ); ?>" type="text" value="<?php echo esc_attr( $pastlimit ); ?>" /><br>
				</div>
				<div id="singlegig" class="drilldownfields">
					<label for="<?php echo $this->get_field_id( 'gigslug' ); ?>">Gig Slug</label> 
					<input class="widefat" id="<?php echo $this->get_field_id( 'gigslug' ); ?>" name="<?php echo $this->get_field_name( 'gigslug' ); ?>" type="text" value="<?php echo esc_attr( $gigslug ); ?>" /><br>
				</div>
				<div id="daterange" class="drilldownfields">
					<label for="<?php echo $this->get_field_id( 'startdate' ); ?>">Start Date</label> 
					<input class="widefat datefield datepicker" id="<?php echo $this->get_field_id( 'startdate' ); ?>" name="<?php echo $this->get_field_name( 'startdate' ); ?>" type="text" value="<?php echo esc_attr( $startdate ); ?>" /><br>
					<label for="<?php echo $this->get_field_id( 'enddate' ); ?>">End Date</label> 
					<input class="widefat datefield datepicker" id="<?php echo $this->get_field_id( 'enddate' ); ?>" name="<?php echo $this->get_field_name( 'enddate' ); ?>" type="text" value="<?php echo esc_attr( $enddate ); ?>" /><br>
					<label for="<?php echo $this->get_field_id( 'rangelimit' ); ?>">Limit</label> 
					<input class="widefat" id="<?php echo $this->get_field_id( 'rangelimit' ); ?>" name="<?php echo $this->get_field_name( 'rangelimit' ); ?>" type="text" value="<?php echo esc_attr( $rangelimit ); ?>" /><br>
				</div>
				
			<label for="<?php echo $this->get_field_id( 'template' ); ?>">Template</label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'template' ); ?>" name="<?php echo $this->get_field_name( 'template' ); ?>">
				<option value="minimal" <?php if($template=="minimal") echo "selected";?>>Minimal</option>
				<option value="basic" <?php if($template=="basic") echo "selected";?>>Basic</option>
				<option value="detailednoimg" <?php if($template=="detailednoimg") echo "selected";?>>Detailed - No Image</option>
				<option value="detailed" <?php if($template=="detailed") echo "selected";?>>Detailed</option>
			</select>
			
			<label for="<?php echo $this->get_field_id( 'orderby' ); ?>">Order By</label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>">
				<option value="DESC" <?php if($orderby=="DESC") echo "selected";?>>Newest First</option>
				<option value="ASC" <?php if($orderby=="ASC") echo "selected";?>>Oldest First</option>
			</select>
		</div>
		<?php 
	}
	public function update( $new_instance, $old_instance ) 
	{
		$instance = array();
		$instance['title'] = strip_tags( $new_instance['title']);
		$instance['querytype'] = strip_tags( $new_instance['querytype']);
		$instance['template'] = strip_tags( $new_instance['template']);
		$instance['futurelimit'] = strip_tags( $new_instance['futurelimit']);
		$instance['pastlimit'] = strip_tags( $new_instance['pastlimit']);
		$instance['gigslug'] = strip_tags( $new_instance['gigslug']);
		$instance['startdate'] = strip_tags( $new_instance['startdate']);
		$instance['enddate'] = strip_tags( $new_instance['enddate']);
		$instance['rangelimit'] = strip_tags( $new_instance['rangelimit']);
		$instance['orderby'] = strip_tags( $new_instance['orderby']);
		return $instance;
	}
}
function load_gig_widget() {
	register_widget( 'band_gig_widget' );
}
add_action( 'widgets_init', 'load_gig_widget' );